@@ -560,7 +560,8 @@ gs_folders_convert (void)
 			"org.gnome.FileRoller.desktop",
 			"gnome-calculator.desktop",
 			"gnome-dictionary.desktop",
-			"gnome-disks.desktop",
+			"org.gnome.Characters.desktop",
+			"org.gnome.DiskUtility.desktop",
 			"org.gnome.font-viewer.desktop",
 			"org.gnome.Screenshot.desktop",
 			"gnome-system-log.desktop",
