@@ -25,7 +25,6 @@
 #include <packagekit-glib2/packagekit.h>
 #include <polkit/polkit.h>
 
-#include "gs-cleanup.h"
 #include "gs-offline-updates.h"
 #include "gs-utils.h"
 
@@ -198,7 +197,7 @@ insert_details_widget (GtkMessageDialog *dialog, const gchar *details)
 	GtkWidget *box, *tv;
 	GtkTextBuffer *buffer;
 	GList *children;
-	_cleanup_string_free_ GString *msg = NULL;
+	g_autoptr(GString) msg = NULL;
 
 	if (!details)
 		return;
@@ -265,8 +264,8 @@ gs_offline_updates_show_error (GsShell *shell)
 	const gchar *secondary;
 	const gchar *geeky;
 	GtkWidget *dialog;
-	_cleanup_object_unref_ PkError *pk_error = NULL;
-	_cleanup_object_unref_ PkResults *results = NULL;
+	g_autoptr(PkError) pk_error = NULL;
+	g_autoptr(PkResults) results = NULL;
 
 	results = pk_offline_get_results (NULL);
 	if (results == NULL)
