@@ -27,7 +27,6 @@
 #include <glib/gstdio.h>
 
 #include "gs-app.h"
-#include "gs-cleanup.h"
 #include "gs-markdown.h"
 #include "gs-plugin.h"
 #include "gs-plugin-loader.h"
@@ -40,7 +39,7 @@ gs_markdown_func (void)
 	gchar *text;
 	const gchar *markdown;
 	const gchar *markdown_expected;
-	_cleanup_object_unref_ GsMarkdown *md = NULL;
+	g_autoptr(GsMarkdown) md = NULL;
 
 	/* get GsMarkdown object */
 	md = gs_markdown_new (GS_MARKDOWN_OUTPUT_PANGO);
@@ -276,8 +275,8 @@ gs_plugin_func (void)
 static void
 gs_app_subsume_func (void)
 {
-	_cleanup_object_unref_ GsApp *new = NULL;
-	_cleanup_object_unref_ GsApp *old = NULL;
+	g_autoptr(GsApp) new = NULL;
+	g_autoptr(GsApp) old = NULL;
 
 	new = gs_app_new ("xxx.desktop");
 	old = gs_app_new ("yyy.desktop");
@@ -289,7 +288,7 @@ gs_app_subsume_func (void)
 static void
 gs_app_func (void)
 {
-	_cleanup_object_unref_ GsApp *app = NULL;
+	g_autoptr(GsApp) app = NULL;
 
 	app = gs_app_new ("gnome-software");
 	g_assert (GS_IS_APP (app));
@@ -328,9 +327,9 @@ gs_plugin_loader_status_changed_cb (GsPluginLoader *plugin_loader,
 static void
 gs_plugin_loader_dedupe_func (void)
 {
-	_cleanup_object_unref_ GsApp *app1 = NULL;
-	_cleanup_object_unref_ GsApp *app2 = NULL;
-	_cleanup_object_unref_ GsPluginLoader *loader = NULL;
+	g_autoptr(GsApp) app1 = NULL;
+	g_autoptr(GsApp) app2 = NULL;
+	g_autoptr(GsPluginLoader) loader = NULL;
 
 	loader = gs_plugin_loader_new ();
 
@@ -358,7 +357,7 @@ gs_plugin_loader_func (void)
 	GList *list;
 	GList *l;
 	GsApp *app;
-	_cleanup_object_unref_ GsPluginLoader *loader = NULL;
+	g_autoptr(GsPluginLoader) loader = NULL;
 
 	/* not avaiable in make distcheck */
 	if (!g_file_test (GS_MODULESETDIR, G_FILE_TEST_EXISTS))
@@ -498,8 +497,8 @@ gs_plugin_loader_refine_func (void)
 	GError *error = NULL;
 	const gchar *url;
 	gboolean ret;
-	_cleanup_object_unref_ GsApp *app = NULL;
-	_cleanup_object_unref_ GsPluginLoader *loader = NULL;
+	g_autoptr(GsApp) app = NULL;
+	g_autoptr(GsPluginLoader) loader = NULL;
 
 	/* not avaiable in make distcheck */
 	if (!g_file_test (GS_MODULESETDIR, G_FILE_TEST_EXISTS))
@@ -543,12 +542,12 @@ gs_plugin_loader_empty_func (void)
 	GList *apps;
 	GList *l;
 	GList *l2;
-	GList *list;
 	GList *subcats;
 	GsCategory *category;
 	GsCategory *sub;
 	guint empty_subcats_cnt = 0;
-	_cleanup_object_unref_ GsPluginLoader *loader = NULL;
+	g_autoptr(GsAppList) list = NULL;
+	g_autoptr(GsPluginLoader) loader = NULL;
 
 	/* not avaiable in make distcheck */
 	if (!g_file_test (GS_MODULESETDIR, G_FILE_TEST_EXISTS))
@@ -621,8 +620,6 @@ gs_plugin_loader_empty_func (void)
 		g_list_free (subcats);
 	}
 	g_assert_cmpint (empty_subcats_cnt, ==, 0);
-
-	gs_plugin_list_free (list);
 }
 
 static void
@@ -630,9 +627,9 @@ gs_plugin_loader_webapps_func (void)
 {
 	gboolean ret;
 	GError *error = NULL;
-	_cleanup_free_ gchar *path = NULL;
-	_cleanup_object_unref_ GsApp *app = NULL;
-	_cleanup_object_unref_ GsPluginLoader *loader = NULL;
+	g_autofree gchar *path = NULL;
+	g_autoptr(GsApp) app = NULL;
+	g_autoptr(GsPluginLoader) loader = NULL;
 
 	/* not avaiable in make distcheck */
 	if (!g_file_test (GS_MODULESETDIR, G_FILE_TEST_EXISTS))
