@@ -29,7 +29,6 @@
 
 #include "gs-plugin-loader-sync.h"
 
-#include "gs-cleanup.h"
 #include "gs-shell-search-provider-generated.h"
 #include "gs-shell-search-provider.h"
 
@@ -41,8 +40,6 @@ typedef struct {
 struct _GsShellSearchProvider {
 	GObject parent;
 
-	guint name_owner_id;
-	GDBusObjectManagerServer *object_manager;
 	GsShellSearchProvider2 *skeleton;
 	GsPluginLoader *plugin_loader;
 	GCancellable *cancellable;
@@ -82,13 +79,15 @@ search_done_cb (GObject *source,
 {
 	PendingSearch *search = user_data;
 	GsShellSearchProvider *self = search->provider;
-	GList *list, *l;
+	GList *l;
 	GVariantBuilder builder;
+	g_autoptr(GsAppList) list = NULL;
 
 	list = gs_plugin_loader_search_finish (self->plugin_loader, res, NULL);
 	if (list == NULL) {
 		g_dbus_method_invocation_return_value (search->invocation, g_variant_new ("(as)", NULL));
 		pending_search_free (search);
+		g_application_release (g_application_get_default ());
 		return;	
 	}
 
@@ -104,8 +103,8 @@ search_done_cb (GObject *source,
 	}
 	g_dbus_method_invocation_return_value (search->invocation, g_variant_new ("(as)", &builder));
 
-	g_list_free_full (list, g_object_unref);
 	pending_search_free (search);
+	g_application_release (g_application_get_default ());
 }
 
 static void
@@ -114,7 +113,7 @@ execute_search (GsShellSearchProvider  *self,
 		gchar		 **terms)
 {
 	PendingSearch *pending_search;
-	_cleanup_free_ gchar *string = NULL;
+	g_autofree gchar *string = NULL;
 
 	string = g_strjoinv (" ", terms);
 
@@ -134,6 +133,7 @@ execute_search (GsShellSearchProvider  *self,
 	pending_search->provider = self;
 	pending_search->invocation = g_object_ref (invocation);
 
+	g_application_hold (g_application_get_default ());
 	self->cancellable = g_cancellable_new ();
 	gs_plugin_loader_search_async (self->plugin_loader,
 				       string, 0, self->cancellable,
@@ -185,7 +185,7 @@ handle_get_result_metas (GsShellSearchProvider2	*skeleton,
 	g_debug ("****** GetResultMetas");
 
 	for (i = 0; results[i]; i++) {
-		_cleanup_object_unref_ GsApp *app = NULL;
+		g_autoptr(GsApp) app = NULL;
 
 		if (g_hash_table_lookup (self->metas_cache, results[i]))
 			continue;
@@ -238,7 +238,7 @@ handle_activate_result (GsShellSearchProvider2 	     *skeleton,
 			gpointer		      user_data)
 {
 	GApplication *app = g_application_get_default ();
-	_cleanup_free_ gchar *string = NULL;
+	g_autofree gchar *string = NULL;
 
 	string = g_strjoinv (" ", terms);
 
@@ -257,7 +257,7 @@ handle_launch_search (GsShellSearchProvider2 	   *skeleton,
 		      gpointer		      user_data)
 {
 	GApplication *app = g_application_get_default ();
-	_cleanup_free_ gchar *string = g_strjoinv (" ", terms);
+	g_autofree gchar *string = g_strjoinv (" ", terms);
 
 	g_action_group_activate_action (G_ACTION_GROUP (app), "search",
 				  	g_variant_new ("s", string));
@@ -266,30 +266,49 @@ handle_launch_search (GsShellSearchProvider2 	   *skeleton,
 	return TRUE;
 }
 
-static void
-search_provider_name_acquired_cb (GDBusConnection *connection,
-				  const gchar     *name,
-				  gpointer	 user_data)
+gboolean
+gs_shell_search_provider_register (GsShellSearchProvider *self,
+                                   GDBusConnection       *connection,
+                                   GError               **error)
 {
-	g_debug ("Search provider name acquired: %s", name);
+	return g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (self->skeleton),
+	                                         connection,
+	                                         "/org/gnome/Software/SearchProvider", error);
+}
+
+void
+gs_shell_search_provider_unregister (GsShellSearchProvider *self)
+{
+	g_dbus_interface_skeleton_unexport (G_DBUS_INTERFACE_SKELETON (self->skeleton));
 }
 
 static void
-search_provider_name_lost_cb (GDBusConnection *connection,
-			      const gchar     *name,
-			      gpointer	 user_data)
+search_provider_dispose (GObject *obj)
 {
-	g_debug ("Search provider name lost: %s", name);
+	GsShellSearchProvider *self = GS_SHELL_SEARCH_PROVIDER (obj);
+
+	if (self->cancellable != NULL) {
+		g_cancellable_cancel (self->cancellable);
+		g_clear_object (&self->cancellable);
+	}
+
+	if (self->metas_cache != NULL) {
+		g_hash_table_destroy (self->metas_cache);
+		self->metas_cache = NULL;
+	}
+
+	g_clear_object (&self->plugin_loader);
+	g_clear_object (&self->skeleton);
+
+	G_OBJECT_CLASS (gs_shell_search_provider_parent_class)->dispose (obj);
 }
 
 static void
-search_provider_bus_acquired_cb (GDBusConnection *connection,
-				 const gchar *name,
-				 gpointer user_data)
+gs_shell_search_provider_init (GsShellSearchProvider *self)
 {
-	GsShellSearchProvider *self = user_data;
+	self->metas_cache = g_hash_table_new_full (g_str_hash, g_str_equal,
+						   g_free, (GDestroyNotify) g_variant_unref);
 
-	self->object_manager = g_dbus_object_manager_server_new ("/org/gnome/Software/SearchProvider");
 	self->skeleton = gs_shell_search_provider2_skeleton_new ();
 
 	g_signal_connect (self->skeleton, "handle-get-initial-result-set",
@@ -302,66 +321,6 @@ search_provider_bus_acquired_cb (GDBusConnection *connection,
 			G_CALLBACK (handle_activate_result), self);
 	g_signal_connect (self->skeleton, "handle-launch-search",
 			G_CALLBACK (handle_launch_search), self);
-
-	g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (self->skeleton),
-					connection,
-					"/org/gnome/Software/SearchProvider", NULL);
-	g_dbus_object_manager_server_set_connection (self->object_manager, connection);
-}
-
-static void
-search_provider_dispose (GObject *obj)
-{
-	GsShellSearchProvider *self = GS_SHELL_SEARCH_PROVIDER (obj);
-
-	if (self->name_owner_id != 0) {
-		g_bus_unown_name (self->name_owner_id);
-		self->name_owner_id = 0;
-	}
-
-	if (self->skeleton != NULL) {
-		g_dbus_interface_skeleton_unexport (G_DBUS_INTERFACE_SKELETON (self->skeleton));
-		g_clear_object (&self->skeleton);
-	}
-
-	if (self->cancellable != NULL) {
-		g_cancellable_cancel (self->cancellable);
-		g_clear_object (&self->cancellable);
-	}
-
-	if (self->metas_cache != NULL) {
-		g_hash_table_destroy (self->metas_cache);
-		self->metas_cache = NULL;
-	}
-
-	g_clear_object (&self->object_manager);
-	g_clear_object (&self->plugin_loader);
-
-	G_OBJECT_CLASS (gs_shell_search_provider_parent_class)->dispose (obj);
-}
-
-static void
-search_provider_finalize (GObject *obj)
-{
-	g_application_release (g_application_get_default ());
-
-	G_OBJECT_CLASS (gs_shell_search_provider_parent_class)->finalize (obj);
-}
-
-static void
-gs_shell_search_provider_init (GsShellSearchProvider *self)
-{
-	self->metas_cache = g_hash_table_new_full (g_str_hash, g_str_equal,
-						   g_free, (GDestroyNotify) g_variant_unref);
-
-	g_application_hold (g_application_get_default ());
-	self->name_owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
-					"org.gnome.Software.SearchProvider",
-					G_BUS_NAME_OWNER_FLAGS_NONE,
-					search_provider_bus_acquired_cb,
-					search_provider_name_acquired_cb,
-					search_provider_name_lost_cb,
-					self, NULL);
 }
 
 static void
@@ -370,7 +329,6 @@ gs_shell_search_provider_class_init (GsShellSearchProviderClass *klass)
 	GObjectClass *oclass = G_OBJECT_CLASS (klass);
 
 	oclass->dispose = search_provider_dispose;
-	oclass->finalize = search_provider_finalize;
 }
 
 GsShellSearchProvider *
