@@ -488,19 +488,25 @@ gs_plugin_refine_item (GsPlugin *plugin,
 		case AS_APP_SOURCE_KIND_METAINFO:
 			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
 			break;
-		case AS_APP_SOURCE_KIND_APPSTREAM:
-			gs_app_set_state (app, as_app_get_state (item));
-			break;
 		default:
 			break;
 		}
 	}
 
-	/* give the desktopdb plugin a fighting chance */
-	if (as_app_get_source_file (item) != NULL &&
-	    gs_app_get_metadata_item (app, "DataDir::desktop-filename") == NULL) {
-		gs_app_set_metadata (app, "DataDir::desktop-filename",
-				     as_app_get_source_file (item));
+	/* allow the PackageKit plugin to match up installed local files
+	 * with packages when the component isn't in the AppStream XML */
+	switch (as_app_get_source_kind (item)) {
+	case AS_APP_SOURCE_KIND_DESKTOP:
+	case AS_APP_SOURCE_KIND_APPDATA:
+	case AS_APP_SOURCE_KIND_METAINFO:
+		if (as_app_get_source_file (item) != NULL &&
+		    gs_app_get_metadata_item (app, "DataDir::desktop-filename") == NULL) {
+			gs_app_set_metadata (app, "DataDir::desktop-filename",
+					     as_app_get_source_file (item));
+		}
+		break;
+	default:
+		break;
 	}
 
 	/* set id */
