@@ -26,7 +26,6 @@
 #include <sqlite3.h>
 #include <stdlib.h>
 
-#include "gs-cleanup.h"
 #include <gs-plugin.h>
 #include <gs-utils.h>
 
@@ -51,7 +50,7 @@ gs_plugin_get_name (void)
 void
 gs_plugin_initialize (GsPlugin *plugin)
 {
-	_cleanup_object_unref_ GSettings *settings = NULL;
+	g_autoptr(GSettings) settings = NULL;
 
 	plugin->priv = GS_PLUGIN_GET_PRIVATE (GsPluginPrivate);
 
@@ -129,9 +128,9 @@ gs_plugin_app_set_usage_pkg (GsPlugin *plugin,
 			     GError **error)
 {
 	guint status_code;
-	_cleanup_free_ gchar *data = NULL;
-	_cleanup_free_ gchar *uri = NULL;
-	_cleanup_object_unref_ SoupMessage *msg = NULL;
+	g_autofree gchar *data = NULL;
+	g_autofree gchar *uri = NULL;
+	g_autoptr(SoupMessage) msg = NULL;
 
 	/* create the PUT data */
 	uri = g_strdup_printf ("%s/api/v1/usage/%s/",
